@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2019 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.  You may
@@ -396,7 +396,7 @@ struct _ImageInfo
     quality;
 
   char
-    *sampling_factor,
+    *sampling_factor,  /* Chroma subsampling ratio string */
     *server_name,
     *font,
     *texture,
