@@ -26,24 +26,25 @@ extern "C" {
   Define declarations.
 */
 #define MagickPackageName "ImageMagick"
-#define MagickCopyright  "(C) 1999-2021 ImageMagick Studio LLC"
+#define MagickCopyright  "(C) 1999 ImageMagick Studio LLC"
 #define MagickLibVersion  0x69C
 #define MagickLibVersionText  "6.9.12"
 #define MagickLibVersionNumber  7,0,0
-#define MagickLibAddendum  "-38"
+#define MagickLibAddendum  "-63"
 #define MagickLibInterface  7
 #define MagickLibMinInterface  7
-#define MagickPlatform  "aarch64"
+#define MagickPlatform  "x86_64"
 #define MagickppLibVersionText  "6.9.12"
 #define MagickppLibVersionNumber  9:0:0
-#define MagickppLibAddendum  "-38"
+#define MagickppLibAddendum  "-63"
 #define MagickppLibInterface  9
 #define MagickppLibMinInterface  9
-#define MagickReleaseDate  "2022-02-05"
+#define MagickGitRevision  "17457"
+#define MagickReleaseDate  "2022-09-11"
 #define MagickHomeURL  "file:///usr/local/share/doc/ImageMagick/index.html"
 #define MagickAuthoritativeLicense  \
   "https://imagemagick.org/script/license.php"
-#define MagickAuthoritativeURL  "https://imagemagick.org"
+#define MagickAuthoritativeURL  "https://legacy.imagemagick.org"
 #if (MAGICKCORE_QUANTUM_DEPTH == 8)
 #define MagickQuantumDepth  "Q8"
 #define MagickQuantumRange  "255"
@@ -68,7 +69,7 @@ extern "C" {
 #define MagickVersion  \
   MagickPackageName " " MagickLibVersionText MagickLibAddendum " " \
   MagickQuantumDepth MagickHDRISupport " " MagickPlatform " " \
-  MagickReleaseDate " " MagickAuthoritativeURL
+  MagickGitRevision " " MagickAuthoritativeURL
 
 extern MagickExport char
   *GetMagickHomeURL(void);
